@@ -1083,8 +1083,12 @@ class Median(GroupByShift):
         return npartitions
 
 
+def groupby_get_group(df, *by_key, get_key=None, columns=None):
+    return _groupby_get_group(df, list(by_key), get_key, columns)
+
+
 class GetGroup(Blockwise, GroupByBase):
-    operation = staticmethod(_groupby_get_group)
+    operation = staticmethod(groupby_get_group)
     _parameters = ["frame", "get_key", "columns"]
     _keyword_only = ["get_key", "columns"]
 
